import { Plugin, PluginServiceApi, Builder } from "@cloudbase/framework-core";
export interface IFunctionPluginInputs {
    functionRootPath: string;
    functions: any[];
    servicePaths?: Record<string, string>;
}
declare class FunctionPlugin extends Plugin {
    name: string;
    api: PluginServiceApi;
    inputs: IFunctionPluginInputs;
    protected resolvedInputs: any;
    protected buildOutput: any;
    protected functions: any[];
    protected functionRootPath: string;
    protected builder: FunctionBuilder;
    protected outputs: Record<string, any>;
    constructor(name: string, api: PluginServiceApi, inputs: IFunctionPluginInputs);
    /**
     * 初始化
     */
    init(): Promise<void>;
    compile(): Promise<{
        Resources: any;
    }>;
    /**
     * 执行本地命令
     */
    run(): Promise<void>;
    /**
     * 删除资源
     */
    remove(): Promise<void>;
    /**
     * 生成代码
     */
    genCode(): Promise<void>;
    /**
     * 构建
     */
    build(): Promise<void>;
    /**
     * 部署
     */
    deploy(): Promise<void>;
    functionConfigToSAM(functionConfig: any): {
        Type: string;
        Properties: {
            Handler: any;
            Description: string;
            Runtime: any;
            FunctionName: any;
            MemorySize: any;
            Timeout: any;
            Environment: any;
            VpcConfig: any;
            HttpPath: any;
            InstallDependency: any;
            CodeUri: any;
            Role: string;
        };
    };
    toConstantCase(name: string): string;
    uploadToCos(localPath: string, cloudPath: string): Promise<string>;
}
interface FunctionBuilderBuildOptions {
    name: string;
    localPath: string;
    zipfileName: string;
}
interface FunctionBuilderOptions {
    /**
     * 项目根目录的绝对路径
     */
    projectPath: string;
}
export declare class FunctionBuilder extends Builder {
    constructor(options: FunctionBuilderOptions);
    build(options: FunctionBuilderBuildOptions[]): Promise<{
        functions: {
            name: string;
            options: {};
            source: string;
            entry: string;
        }[];
    }>;
    zipDir(src: string, dest: string): Promise<unknown>;
}
export declare const plugin: typeof FunctionPlugin;
export {};
//# sourceMappingURL=index.d.ts.map